@@ -6,6 +6,6 @@ CLOSURE = Optional[Callable[[], float]]
 LOSS = Optional[float]
 BETAS = Tuple[float, float]
 DEFAULTS = Dict[str, Any]
-PARAMETERS = Union[Iterable[Dict[str, Any]], Iterable[torch.Tensor]]
+PARAMETERS = Optional[Union[Iterable[Dict[str, Any]], Iterable[torch.Tensor]]]
 STATE = Dict[str, Any]
 BUFFER = List[List[Optional[torch.Tensor]]]
